==> alg-feature-2.16.0-sources.jar: cn/com/duiba/nezha/alg/feature/vo/ActInterceptFeatureDo.java <==
package cn.com.duiba.nezha.alg.feature.vo;

import java.io.Serializable;

/**
 * Created by pc on 2019/2/21.
 */
public class ActInterceptFeatureDo implements Serializable {
    private static final long serialVersionUID = 6695201251295150673L;


    /**
     * 静态特征，推荐入参提供
     */

    private Long appId; //媒体ID f.请求 f201000-f201001

    private Long slotId;  //广告位ID f.请求 f108000-f108001


    private Long mainActivityId; //主活动ID.请求

    private Long mainActivityJoinTimes; //主活动参与次数.请求


    private String activitySkin; //主活动皮肤ID f.请求 新增，待编码

    private Long dsm2A; //返回拦截类型 f.请求 新增，待编码  312001


    private Long areaCode; // 地域 f4010030


    /**
     * 动态特征，打印日志补全、算法推荐内部补全
     */
    private Long activityId; //返回拦截活动活动IDf.请求 f302000-f302001

    private ActInterceptStatDo  actInterceptStatDo ;//返回拦截活动统计数据

    private String  consumerAdFeature ;//用户广告特征



    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getMainActivityId() {
        return mainActivityId;
    }

    public void setMainActivityId(Long mainActivityId) {
        this.mainActivityId = mainActivityId;
    }

    public Long getMainActivityJoinTimes() {
        return mainActivityJoinTimes;
    }

    public void setMainActivityJoinTimes(Long mainActivityJoinTimes) {
        this.mainActivityJoinTimes = mainActivityJoinTimes;
    }

    public String getActivitySkin() {
        return activitySkin;
    }

    public void setActivitySkin(String activitySkin) {
        this.activitySkin = activitySkin;
    }

    public Long getDsm2A() {
        return dsm2A;
    }

    public void setDsm2A(Long dsm2A) {
        this.dsm2A = dsm2A;
    }

    public Long getAreaCode() {
        return areaCode;
    }

    public void setAreaCode(Long areaCode) {
        this.areaCode = areaCode;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public ActInterceptStatDo getActInterceptStatDo() {
        return actInterceptStatDo;
    }

    public void setActInterceptStatDo(ActInterceptStatDo actInterceptStatDo) {
        this.actInterceptStatDo = actInterceptStatDo;
    }

    public String getConsumerAdFeature() {
        return consumerAdFeature;
    }

    public void setConsumerAdFeature(String consumerAdFeature) {
        this.consumerAdFeature = consumerAdFeature;
    }

}

==> alg-feature-2.21.13-20201022.115203-1-sources.jar: cn/com/duiba/nezha/alg/feature/vo/ActInterceptFeatureDo.java <==
package cn.com.duiba.nezha.alg.feature.vo;

import java.io.Serializable;

/**
 * Created by pc on 2019/2/21.
 */
public class ActInterceptFeatureDo implements Serializable {
    private static final long serialVersionUID = 6695201251295150673L;


    /**
     * 静态特征，推荐入参提供
     */

    private Long appId; //媒体ID f.请求 f201000-f201001

    private Long slotId;  //广告位ID f.请求 f108000-f108001


    private Long mainActivityId; //主活动ID.请求

    private Long mainActivityJoinTimes; //主活动参与次数.请求


    private String activitySkin; //主活动皮肤ID f.请求 新增，待编码

    private Long dsm2A; //返回拦截类型 f.请求 新增，待编码  312001


    private Long areaCode; // 地域 f4010030


    /**
     * 动态特征，打印日志补全、算法推荐内部补全
     */
    private Long activityId; //返回拦截活动活动IDf.请求 f302000-f302001

    private ActInterceptStatDo  actInterceptStatDo ;//返回拦截活动统计数据

    /**
     * 动态特征，打印日志补全、算法推荐内部补全
     */
    private Long plugId; //返回拦截活动插件IDf.请求


    private PlugInterceptStatDo  plugInterceptStatDo ;//返回拦截插件统计数据




    private String  consumerAdFeature ;//用户广告特征



    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getMainActivityId() {
        return mainActivityId;
    }

    public void setMainActivityId(Long mainActivityId) {
        this.mainActivityId = mainActivityId;
    }

    public Long getMainActivityJoinTimes() {
        return mainActivityJoinTimes;
    }

    public void setMainActivityJoinTimes(Long mainActivityJoinTimes) {
        this.mainActivityJoinTimes = mainActivityJoinTimes;
    }

    public String getActivitySkin() {
        return activitySkin;
    }

    public void setActivitySkin(String activitySkin) {
        this.activitySkin = activitySkin;
    }

    public Long getDsm2A() {
        return dsm2A;
    }

    public void setDsm2A(Long dsm2A) {
        this.dsm2A = dsm2A;
    }

    public Long getAreaCode() {
        return areaCode;
    }

    public void setAreaCode(Long areaCode) {
        this.areaCode = areaCode;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getPlugId() {
        return plugId;
    }

    public void setPlugId(Long plugId) {
        this.plugId = plugId;
    }

    public ActInterceptStatDo getActInterceptStatDo() {
        return actInterceptStatDo;
    }

    public void setActInterceptStatDo(ActInterceptStatDo actInterceptStatDo) {
        this.actInterceptStatDo = actInterceptStatDo;
    }

    public PlugInterceptStatDo getPlugInterceptStatDo() {
        return plugInterceptStatDo;
    }

    public void setPlugInterceptStatDo(PlugInterceptStatDo plugInterceptStatDo) {
        this.plugInterceptStatDo = plugInterceptStatDo;
    }

    public String getConsumerAdFeature() {
        return consumerAdFeature;
    }

    public void setConsumerAdFeature(String consumerAdFeature) {
        this.consumerAdFeature = consumerAdFeature;
    }

}
